@@ -36,7 +36,7 @@
 #include <QVBoxLayout>
 #include <QPrinter>
 
-#include <KDebug>
+#include "kpLogCategories.h"
 #include <KLocalizedString>
 
 #include "kpDefs.h"
@@ -52,7 +52,7 @@ kpPrintDialogPage::kpPrintDialogPage (QWidget *parent)
       d (new kpPrintDialogPagePrivate ())
 {
 #if DEBUG_KP_PRINT_DIALOG_PAGE
-    kDebug () << "kpPrintDialogPage::<ctor>()";
+    qCDebug(kpLogWidgets) << "kpPrintDialogPage::<ctor>()";
 #endif
 
     setWindowTitle (i18nc ("@title:tab", "I&mage Position"));
@@ -79,7 +79,7 @@ kpPrintDialogPage::~kpPrintDialogPage ()
 bool kpPrintDialogPage::printImageCenteredOnPage ()
 {
 #if DEBUG_KP_PRINT_DIALOG_PAGE
-    kDebug () << "kpPrintDialogPage::printImageCenteredOnPage()"
+    qCDebug(kpLogWidgets) << "kpPrintDialogPage::printImageCenteredOnPage()"
               << " returning " << d->printCenteredRadio->isChecked() << endl;
 #endif
     return d->printCenteredRadio->isChecked ();
@@ -89,7 +89,7 @@ bool kpPrintDialogPage::printImageCenteredOnPage ()
 void kpPrintDialogPage::setPrintImageCenteredOnPage (bool printCentered)
 {
 #if DEBUG_KP_PRINT_DIALOG_PAGE
-    kDebug () << "kpPrintDialogPage::setOptions(" << printCentered << ")";
+    qCDebug(kpLogWidgets) << "kpPrintDialogPage::setOptions(" << printCentered << ")";
 #endif
     if (printCentered)
         d->printCenteredRadio->setChecked (true);
